@@ -1,15 +1,16 @@
+from typing import Optional
 from pydantic import BaseModel
 
 from otobo_znuny.models.ticket_models import WsTicketOutput
 
 
 class WsTicketResponse(BaseModel):
-    Ticket: WsTicketOutput | None = None
+    Ticket: Optional[WsTicketOutput] = None
 
 
 class WsTicketGetResponse(BaseModel):
-    Ticket: list[WsTicketOutput]
+    Ticket: list[WsTicketOutput] = []
 
 
 class WsTicketSearchResponse(BaseModel):
-    TicketID: list[int] | None = None
+    TicketID: Optional[list[int]] = None
